@@ -82,7 +82,7 @@ def main():
     identifier = config.get('_IDENTIFIER')
 
     registry_address = to_checksum_address(config.get('_EXEC_ADDRESS'))
-    if not config.true('_UNSAFE') and registry_address != add_0x(config.get('_EXEC_ADDRESS')):
+    if not config.true('_UNSAFE') and strip_0x(registry_address) != strip_0x(config.get('_EXEC_ADDRESS')):
         raise ValueError('invalid checksum address for contract')
 
     if identifier != None:
