@@ -63,11 +63,11 @@ def main():
     c = ContractRegistry(chain_spec, signer=signer, gas_oracle=gas_oracle, nonce_oracle=nonce_oracle)
 
     subject_address = to_checksum_address(config.get('_ADDRESS'))
-    if not config.true('_UNSAFE') and subject_address != add_0x(config.get('_ADDRESS')):
+    if not config.true('_UNSAFE') and strip_0x(subject_address) != strip_0x(config.get('_ADDRESS')):
         raise ValueError('invalid checksum address for subject_address')
 
     registry_address = to_checksum_address(config.get('_EXEC_ADDRESS'))
-    if not config.true('_UNSAFE') and registry_address != add_0x(config.get('_EXEC_ADDRESS')):
+    if not config.true('_UNSAFE') and strip_0x(registry_address) != strip_0x(config.get('_EXEC_ADDRESS')):
         raise ValueError('invalid checksum address for contract')
 
     chain_config_hash = config.get('_CHAIN_HASH')
@@ -76,7 +76,7 @@ def main():
         raise ValueError('chain config hash must be 32 bytes')
     chain_config_hash = add_0x(chain_config_hash)
 
-    (tx_hash_hex, o) = c.set(registry_address, signer_address, config.get('_IDENTIFIER'), subject_address, chain_spec, chain_config_hash)
+    (tx_hash_hex, o) = c.set(registry_address, signer_address, config.get('_IDENTIFIER'), subject_address)
 
     if config.get('_RPC_SEND'):
         conn.do(o)
